import { Component, Input, Output, ChangeDetectionStrategy, Renderer, ElementRef, EventEmitter } from '@angular/core';
import { DisqusService } from './disqus.service';
export var DisqusComponent = (function () {
    function DisqusComponent(renderer, el, dService) {
        this.renderer = renderer;
        this.el = el;
        this.dService = dService;
        /** Track Comments */
        this.comment = new EventEmitter();
    }
    DisqusComponent.prototype.ngOnChanges = function (changes) {
        if (!this.dService.disqus) {
            this.addDisqusScript();
        }
        else {
            var idChange = changes['identifier'];
            var urlChange = changes['url'];
            var catChange = changes['categoryId'];
            var titleChange = changes['title'];
            var langChange = changes['language'];
            var isResetNeeded = false;
            if (idChange && idChange.currentValue !== idChange.previousValue) {
                isResetNeeded = true;
            }
            if (urlChange && urlChange.currentValue !== urlChange.previousValue) {
                isResetNeeded = true;
            }
            if (catChange && catChange.currentValue !== catChange.previousValue) {
                isResetNeeded = true;
            }
            if (titleChange && titleChange.currentValue !== titleChange.previousValue) {
                isResetNeeded = true;
            }
            if (langChange && langChange.currentValue !== langChange.previousValue) {
                isResetNeeded = true;
            }
            if (isResetNeeded) {
                this.reset();
            }
        }
    };
    DisqusComponent.prototype.addDisqusScript = function () {
        /** Set disqus config */
        this.dService.disqusConfig = this.getConfig();
        /** Add DISQUS script */
        var diqusScript = this.renderer.createElement(this.el.nativeElement, 'script');
        diqusScript.src = "//" + this.shortname + ".disqus.com/embed.js";
        diqusScript.async = true;
        diqusScript.type = 'text/javascript';
        this.renderer.setElementAttribute(diqusScript, 'data-timestamp', new Date().getTime().toString());
    };
    /** Reset disqus with new inputs. */
    DisqusComponent.prototype.reset = function () {
        this.dService.disqus.reset({
            reload: true,
            config: this.getConfig()
        });
    };
    /** TODO: Get DISQUS Count */
    /** ngAfterViewInit(){
            this.dService.getCount().subscribe((res)=>{
                console.log(res);
            })
        }
    */
    /** Get the valid URL */
    DisqusComponent.prototype.validatedUrl = function () {
        /** If URL is specified then validate it, otherwise use window URL */
        if (this.url) {
            var r = /(http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?/;
            if (r.test(this.url)) {
                return this.url;
            }
            else {
                console.warn('[Disqus]: Invalid URL, fallback to Window URL');
            }
        }
        /** fallback to "Window" URL, or to "Global" in universal */
        return this.dService.url;
    };
    /** Get disqus settings from inputs */
    DisqusComponent.prototype.getConfig = function () {
        var self = this;
        return function () {
            this.page.identifier = self.identifier;
            this.page.url = self.url;
            this.page.title = self.title;
            this.category_id = self.categoryId;
            this.language = self.language;
            /* Available callbacks are afterRender, onInit, onNewComment, onPaginate, onReady, preData, preInit, preReset */
            this.callbacks.onNewComment = [function (comment) {
                    self.comment.emit(comment);
                }];
        };
    };
    DisqusComponent.prototype.ngOnDestroy = function () {
        if (this.dService.window) {
            this.dService.window.DISQUS = undefined;
            this.dService.window.disqusConfig = undefined;
            this.dService.window.DISQUSWIDGETS = undefined;
        }
        else {
            global.DISQUS = undefined;
            global.disqusConfig = undefined;
            global.DISQUSWIDGETS = undefined;
        }
    };
    DisqusComponent.decorators = [
        { type: Component, args: [{
                    selector: 'disqus',
                    template: '<div id="disqus_thread"></div>',
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    DisqusComponent.ctorParameters = [
        { type: Renderer, },
        { type: ElementRef, },
        { type: DisqusService, },
    ];
    DisqusComponent.propDecorators = {
        'shortname': [{ type: Input },],
        'identifier': [{ type: Input },],
        'url': [{ type: Input },],
        'categoryId': [{ type: Input },],
        'language': [{ type: Input },],
        'title': [{ type: Input },],
        'count': [{ type: Input },],
        'removeOnDestroy': [{ type: Input },],
        'comment': [{ type: Output },],
    };
    return DisqusComponent;
}());
//# sourceMappingURL=disqus.component.js.map